#' Parameterize Multivariate Beta (MVB) Distribution
#'
#' \code{paramMVB} returns parameter estimates for a multivariate beta ditribution to best represents a set of observed data using the MoM method
#'
#' @param pmat data matrix where each row is an observation, each column is a feature. Each row must contain a p-vector summing to 1
#'
#' @return vector containing estimates for alpha-paramters for dirchlet (MVBeta) distribution
#'
#' @export


paramMVB <- function(pmat){
  # pmat where i is obs, and each row contains p-vector summing to 1
  # returns estimates for alpha-paramters for dirchlet (MVBeta)

  p1 <- apply(pmat, 2, function(x) mean(x, na.rm = T)) # first moment
  #p2 <- apply(Po, 2, function(x) mean(x, na.rm = T)) # second moment
  p2 <- apply(pmat, 2, function(x) sd(x, na.rm = T))
  p2 <- p1^2 + p2^2

  n <- length(p1)

  myalpha <- c()
  for(i in 1:(n-1)){
    myalpha[i] <- (p1[1] - p2[1]) * p1[i]/(p2[1] -
                                             p1[1]^2)
  }

  myalpha[n] <- ( (p1[1]-p2[1])*(1-sum(p1[-n])) ) /
    (p2[1] - p1[1]^2)

  return(myalpha)

}
