recursiveTestBranch <-  function(obsdat, simdata, rawdata, resultout = NULL, nclustalt = NULL, maxiter = 2000, B = 2000, feature_subset = NULL, dist_method = 'Euclidean', weightdist = NULL, hclust_method = 'ward.D2', logbase = 2, SimSpecs = NULL, showplot = FALSE, verbose = F){

  # if(is.null(feature_subset)){
  #   feature_subset = names(obsdat)
  # }

  if(!is.null(feature_subset)){
    obsdat <- obsdat[ , feature_subset]
    simdata <- simdata[,feature_subset,]
    rawdata <- rawdata[ , , feature_subset]
    if(!is.null((weightdist))){
      weightdist <- weightdist[ , feature_subset]
    }
  }

  #print(rownames(obsdat))

  if(is.null(resultout)){
    resultout <- list()
  }

  if(nrow(obsdat) == 1){ # if node is a leaf, bottom out

    resultout[[length(resultout) + 1]] <- list(Type = 'Cluster',
                                               LeafID = rownames(obsdat))
    return(resultout)

  }

  # get subtree for branch under consideration
  hout <- getEncoding(obsdat,
                        simdata = simdata,
                        hclust_method = hclust_method,
                        dist_method = dist_method,
                        weightdist = weightdist,
                        returnTree = T
  )$hctree %>% as.dendrogram()
  nh <- hout %>% get_nodes_attr("height")


  #print(rownames(obsdat))

  if(sum(nh == 0) == length(nh)){ # if leaves are identical, bottom out

    resultout[[length(resultout) + 1]] <- list(Type = 'Cluster',
                                               LeafID = rownames(obsdat))
    return(resultout)

  }else{ # apply recursion

    #print(dim(obsdat[ , feature_subset]))
    #print(rownames(obsdat))
    #print(round(sqrt(Ntot/nrow(obsdat)) * B))

    branchresult <- testBranch(obsdat, # obsdat[temp,],
                               simdata,# simdata[temp,,],
                               rawdata,# rawdata[temp,,],
                               #B = round(sqrt(Ntot/nrow(obsdat)) * B), # rescale B to account for diminishing branch size (lower confidence MCE estimates) to maintain accuracy if emprical cdf's,
                               B = B,
                               maxiter = maxiter,
                               nclustalt = nclustalt,
                               feature_subset = feature_subset,
                               hclust_method = hclust_method,
                               dist_method = dist_method,
                               weightdist = weightdist,
                               SimSpecs = SimSpecs,
                               logbase = logbase,
                               showplot = showplot,
                               verbose = verbose)

    # tryCatch({
    # branchresult <- testBranch(obsdat, # obsdat[temp,],
    #                          simdata,# simdata[temp,,],
    #                          rawdata,# rawdata[temp,,],
    #                          #B = round(sqrt(Ntot/nrow(obsdat)) * B), # rescale B to account for diminishing branch size (lower confidence MCE estimates) to maintain accuracy if emprical cdf's,
    #                          B = B,
    #                          maxiter = maxiter,
    #                          nclustalt = nclustalt,
    #                          feature_subset = feature_subset,
    #                          hclust_method = hclust_method,
    #                          dist_method = dist_method,
    #                          weightdist = weightdist,
    #                          SimSpecs = SimSpecs,
    #                          logbase = logbase,
    #                          showplot = showplot,
    #                          verbose = verbose)
    # }, warning = function(w) { print(w) }  )
    #print(branchresult$pval)
    #print(branchresult)

    if(!branchresult$sigdiff){

      resultout[[length(resultout) + 1]] <- list(Type = 'Cluster',
                                                 LeafID = rownames(obsdat))
      return(resultout)

    }else{

      resultout[[length(resultout) + 1]] <- list(Type = 'Branch',
                                                 SimResult = branchresult)


      # obscode <- getEncoding(obsdat[ , feature_subset],
      #                          hclust_method = hclust_method)
      obscode <- branchresult$encoding
      resultout <- recursiveTestBranch(obsdat[obscode == 1, ],
                                       simdata[obscode == 1, ,],
                                       rawdata[obscode == 1, ,],
                                       resultout = resultout,
                                       nclustalt = nclustalt,
                                       maxiter = maxiter,
                                       B = B,
                                       feature_subset = feature_subset,
                                       hclust_method = hclust_method,
                                       dist_method = dist_method,
                                       weightdist = weightdist[obscode == 1,],
                                       SimSpecs = SimSpecs,
                                       logbase = logbase,
                                       showplot = showplot,
                                       verbose = verbose
      )
      resultout <- recursiveTestBranch(obsdat[obscode == 2, ],
                                       simdata[obscode == 2, ,],
                                       rawdata[obscode == 2, ,],
                                       resultout = resultout,
                                       nclustalt = nclustalt,
                                       maxiter = maxiter,
                                       B = B,
                                       feature_subset = feature_subset,
                                       hclust_method = hclust_method,
                                       dist_method = dist_method,
                                       weightdist = weightdist[obscode == 2,],
                                       SimSpecs = SimSpecs,
                                       logbase = logbase,
                                       showplot = showplot,
                                       verbose = verbose
      )
    }
  }

}
