## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----setup, message=FALSE-----------------------------------------------------
library(LIT)

library(plotly)
library(dplyr)
library(ggplot2)

## ---- include = FALSE---------------------------------------------------------

cowdat <- read.csv('/Users/catie/Documents/Research/MyPackages/LITPackage/data/eatdat_cow45757.csv')

cowdat$HourCorrected <- NA
cowdat$HourCorrected[cowdat$Hour == 0] <- 19
cowdat$HourCorrected[cowdat$Hour == 1] <- 20
cowdat$HourCorrected[cowdat$Hour == 2] <- 21
cowdat$HourCorrected[cowdat$Hour == 3] <- 22
cowdat$HourCorrected[cowdat$Hour == 4] <- 23
cowdat$HourCorrected[cowdat$Hour == 5] <- 0
cowdat$HourCorrected[cowdat$Hour == 6] <- 1
cowdat$HourCorrected[cowdat$Hour == 7] <- 2
cowdat$HourCorrected[cowdat$Hour == 8] <- 3
cowdat$HourCorrected[cowdat$Hour == 9] <- 4
cowdat$HourCorrected[cowdat$Hour == 10] <- 5
cowdat$HourCorrected[cowdat$Hour == 11] <- 6
cowdat$HourCorrected[cowdat$Hour == 12] <- 7
cowdat$HourCorrected[cowdat$Hour == 13] <- 8
cowdat$HourCorrected[cowdat$Hour == 14] <- 9
cowdat$HourCorrected[cowdat$Hour == 15] <- 10
cowdat$HourCorrected[cowdat$Hour == 16] <- 11
cowdat$HourCorrected[cowdat$Hour == 17] <- 12
cowdat$HourCorrected[cowdat$Hour == 18] <- 13
cowdat$HourCorrected[cowdat$Hour == 19] <- 14
cowdat$HourCorrected[cowdat$Hour == 20] <- 15
cowdat$HourCorrected[cowdat$Hour == 21] <- 16
cowdat$HourCorrected[cowdat$Hour == 22] <- 17
cowdat$HourCorrected[cowdat$Hour == 23] <- 18



## -----------------------------------------------------------------------------

str(cowdat)

cowdat[1:10,]


## ----fig.width = 4------------------------------------------------------------

ggplot(cowdat, aes(x = HourCorrected, y = MinEat)) + 
  geom_point() + 
  geom_smooth(formula = y ~ x, method = 'loess') + 
  ggtitle('Cyclical Eating Pattern: Cow 47575') + 
  ylab('Minutes Spent Eating') + xlab('Hour')

ggplot(cowdat, aes(x = Date, y = MinEat)) + 
  geom_point() + 
  geom_smooth(formula = y ~ x, method = 'loess') + 
  ggtitle('Longitudinal Eating Pattern: Cow 47575') + 
  ylab('Minutes Spent Eating')


## -----------------------------------------------------------------------------

tubeplot(cowdat$HourCorrected, cowdat$Date, cowdat$MinEat, 
         plot_title = 'Eating Pattern of Cow 45757', 
         camera_orient = list(eye = list(x = 1.5, y = 0.5, z = 0))
         )


## -----------------------------------------------------------------------------

tubeplot(cowdat$HourCorrected, cowdat$Date, cowdat$MinEat, 
         plot_title = 'Eating Pattern of Cow 45757', 
         camera_orient = list(eye = list(x = -1.3, y = 1, z = 0))
         )


## -----------------------------------------------------------------------------

tubeplot(cowdat$HourCorrected, cowdat$Date, cowdat$MinEat, 
         plot_title = 'Eating Pattern of Cow 45757',     
         camera_orient = list(eye = list(x = -0.5, y = -1.8, z = 0))
         )


## -----------------------------------------------------------------------------

myannotationkey <- data.frame(
  H = c(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23),
  text = c("7pm",  "8pm",  "9pm",  "10pm", "11pm", "12pm", "1am",  "2am",  "3am",  "4am",  "5am",  "6am",  "7am",  "8am",  "9am",  "10am", "11am", "12am", "1pm",  "2pm",  "3pm",  "4pm",  "5pm",  "6pm")
  )

tubeplot(cowdat$Hour, cowdat$Date, cowdat$MinEat, 
         plot_title = 'Eating Pattern of Cow 45757',
         annotationkey = myannotationkey,
         camera_orient = list(eye = list(x = 0.3, y = 2, z = 0))
         )



## ----eval=FALSE---------------------------------------------------------------
#  
#  tubeplot(cowdat$Hour, cowdat$Date, cowdat$MinEat,
#           plot_title = 'Eating Pattern of Cow 45757',
#           annotationkey = myannotationkey,
#           camera_orient = list(eye = list(x = 0.3, y = 2, z = 0)),
#           showplot = F,
#           export_html = T,
#           filename = '/Viz/EatTube_Cow45757'
#           )
#  

## ----eval=FALSE---------------------------------------------------------------
#  
#  tubeplot(cowdat$Hour, cowdat$Date, cowdat$MinEat,
#           plot_title = 'Eating Pattern of Cow 45757',
#           annotationkey = myannotationkey,
#           camera_orient = list(eye = list(x = 0.3, y = 2, z = 0)),
#           showplot = F,
#           export_html = T,
#           filename = '/Viz/EatTube_Cow45757',
#           orcascale = 5
#           )
#  

## -----------------------------------------------------------------------------

tubeplot(cowdat$Hour, cowdat$Date, cowdat$MinEat, 
         plot_title = 'Eating Pattern of Cow 45757',
         radius = 2,
         annotationkey = myannotationkey,
         camera_orient = list(eye = list(x = 0.3, y = 2, z = 0)),
         marker = list(size = 12),
         colors = 'YlOrRd'
         )


## ---- include = FALSE---------------------------------------------------------

groupdat_eat <- read.csv('/Users/catie/Documents/Research/MyPackages/LITPackage/data/eatdat_CEDAgroup.csv')


## -----------------------------------------------------------------------------

groupdat_eat[1:10,]

eatout <- groupTubeplot(groupdat_eat$Hour, groupdat_eat$Date,
              groupdat_eat[,5:ncol(groupdat_eat),],
              c(2,2,2,2,1,1,1,2,2,2,1,2),
              func = 'mean',
              plot_title = 'Eating Pattern', 
              makediffplot = T,
              returnstats = T,
              annotationkey = myannotationkey,
              camera_orient = list(eye = list(x = 0.3, y = 2, z = 0))
              )

eatout$plots[[1]] # Group 1
eatout$plots[[3]] # Group 2
eatout$plots[[2]] # Diff Plot

eatout$summarydata[1:10,] # summary data for each group


## ---- include = FALSE---------------------------------------------------------

groupdat_rum <- read.csv('/Users/catie/Documents/Research/MyPackages/LITPackage/data/rumdat_CEDAgroup.csv')


## -----------------------------------------------------------------------------

groupdat_rum[1:10,]

rumout <-groupTubeplot(groupdat_rum$Hour, groupdat_rum$Date,
              groupdat_rum[,5:ncol(groupdat_rum),],
              c(2,2,2,2,1,1,1,2,2,2,1,2),
              func = 'mean',
              plot_title = 'Rumination Pattern', 
              makediffplot = T,
              returnstats = T,
              annotationkey = myannotationkey,
              camera_orient = list(eye = list(x = 0.3, y = 2, z = 0))
              )

rumout$plots[[1]] # Group 1
rumout$plots[[3]] # Group 2
rumout$plots[[2]] # Diff Plot

rumout$summarydata[1:10,] # summary data for each group


