% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/KLDdist.R
\name{KLDdist}
\alias{KLDdist}
\title{Calculate KL-Divergence}
\usage{
KLDdist(
  dist1,
  dist2 = NULL,
  isFreq = TRUE,
  logbase = 2,
  returnSymetric = TRUE,
  runfast = FALSE,
  DirichletCorrection = FALSE
)
}
\arguments{
\item{dist1}{May either be a distribution vector, or a dataframe/matrix/2D array wherein each row represents a distribution vector}

\item{dist2}{Optional input. Vector of counts/frequencies for a distribtuion}

\item{isFreq}{Optional logical argument. Default is TRUE, indicating dat has been supplied as pre-normalized frequency vectors. User may provide data in the form of counts distributions if isFreq is FALSE.}

\item{logbase}{Optional argument. Logarithm base to use in computing entropic values. Default is 2 (Shannon's Entropy).}

\item{returnSymetric}{Optional logical argument. Default is TRUE. KL Divergence is not an intrinsically symetric estimator. If TRUE, KL Divergence will be made symmetric by calculating relative entropy using either observed distribution vector as the reference (q) distributions and adding the results. If FALSE, the asymetric relative entropy value will be returned}

\item{runfast}{Optional logical argument. Default if FALSE. If TRUE, data matrix will be passed to Dist utility in the Rdast package to speed up computation of large distance matrices. With this option, only a symmetric dissimlarity metric is returned, log base cannot be modified, and Dirichlets Correction cannot be utilized.}

\item{DirichletCorrection}{Optional logical argument. Default is FALSE. Only availiable when isFreq is FALSE. Should a Dirichlets correction be applied to frequency vectors before relative entropy is calculated. Allows for entropy to be calculated if q may contain 0 due to under-sampling.}
}
\description{
\code{KLDdist} computes the KLDistance, returning a nominal relative entropy value if two distribution vectors are supplied, or a distance matrix if one data frame is supplied.
}
\details{
KL-Divergence calculates the relative entropy between two discrete distributions. The two distributions may be provided either as frequency (normalized to sum to 1) or as count vectors, but must have the same domain of support (ie - be the same length)

If two vectors are supplied, a nominal entropy value is returned, as in the relativeEntropy.

Alternatively a dataframe/matrix/2D array may be provided wherein each row each row represents a distribution vector, for which a dissimilarity matrix is returned representing each combination of pairwise comparisons between rows. If returnSymetric if FALSE, the dissimilarity will be assymetric, as each value in the matrix will represent the relative entropy estimate for which the column index serves as the reference distribution. If returnSymetric is TRUE, the the dissimilarity matrix will be made symetric by summming over the diagonal.

It should be noted that if KLD Distance is being calculated for under-sampled data that may contain zero-counts, relative entropy will be returned as Inf. If data is provided as counts, a Dirchelets correction may be applied to prevent these missing values to facilitate downstream analyses. In general, however, KLD Distance may not be an appropriate dissimilarity statistic for such data, so use this option with due caution.
}
\examples{

set.seed(10)
dist1 <- matrix(rmultinom(5, 100, c(0.2, 0.2, 0.2, 0.2, 0.2)), nrow = 5, ncol = 5)

KLDdist(dist1, isFreq = F, returnSymetric = TRUE)
KLDdist(dist1, isFreq = F, returnSymetric = FALSE)

dist1[1,1] <- 0
KLDdist(dist1, isFreq = F, returnSymetric = TRUE)
KLDdist(dist1, isFreq = F, returnSymetric = FALSE)

KLDdist(dist1, isFreq = F, returnSymetric = TRUE, DirichletCorrection = TRUE)
KLDdist(dist1, isFreq = F, runfast = T)

}
