% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MITest.R
\name{MITest}
\alias{MITest}
\title{Mutual Information Test}
\usage{
MITest(
  codex,
  codey,
  nperm = 1000,
  logbase = 2,
  estimator = "ML",
  rescale = T,
  verbose = F,
  plotresults = F
)
}
\arguments{
\item{codex}{First encoded variable. User may pass either a list object from LIT clustering output (for a single cluster number) or a data frame formatted with named rows and one column containing the encoded variable.}

\item{codey}{Second encoded variable. User may pass either a list object from LIT clustering output (for a single cluster number) or a data frame formatted with named rows and one column containing the encoded variable.}

\item{nperm}{Optional argument. Defualt is 1000. Number of permutations used to simulate the null MI value for each pairwise comparision of candidate tree encodings}

\item{logbase}{Optional argument. Logarithm base to use in computing entropic values. Default is 2 (Shannon's Entropy).}

\item{estimator}{Optional argument. Method employed to estimate empirical frequencies of the joint encoding used to calculate entropic values. Defualt is 'ML'. Bias-corrected estimators available include "shrink", "Jeffreys","Laplace", "SG", "minmax".}

\item{rescale}{Optional logical argument. If TRUE (default), estimator used in permutation tests for signicance of association is MI rescaled by the total entropy of the joint encoding. If FALSE, the raw/unscaled MI estimate is used as the standard of comparison.}

\item{verbose}{Optional logical argument. Default is FALSE. If TRUE additional simulation specs are returned.}

\item{plotresults}{Optional logical argument. Default is FALSE. If TRUE returns a histogram plot of MI values under the null compared to the observed value.}
}
\value{
A named list containing:
\item{PVals}{Integer value. Proportion of MI values simulated under the null that are equal to or larger than the observed value}
\item{ObsEntropy}{Mutual Information estimate of the observed joint encoding}
\item{testSpecs}{Named list of MI test options used to generate simulation results}
\item{ObsEntropy}{Returned only if verbose is TRUE. Named list containing complete output of information theoretic estimates (from calcEntropy) for the observed joint encoding}
\item{NullDis}{Returned only if verbose is TRUE. Vector containing MI values simulated under the null}
\item{Plot}{Returned only if verbose is TRUE. Null if plotresults is FALSE. Visualization of distribution of MI values simulated under the null}
}
\description{
\code{MITest} evaluates if a statistically significant bivariate relationship exists between two discretely encoded variables via a permtuation test that uses mutual information estimator.
}
\details{
MItest compares the observed Mututal information of the observed joint distribution, and compares it to the distribution of MI values calculated under the null using a random permutation of indices to break any bivariate relationships between axes.
}
\examples{

myx <- round(runif(100, 0, 5))
myy <- round(runif(100, 0, 5))

MITest(myx, myy, plotresults = T, verbose = T)


}
