% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compareEncodings.R
\name{compareEncodings}
\alias{compareEncodings}
\title{Generate Visual Comparisons of Encoded Data}
\usage{
compareEncodings(
  encodeout1,
  encodeout2,
  colorby = "count",
  simPMI = NULL,
  nsim = 1000,
  alpha = 0.05,
  logbase = 2,
  gradient_color_low = "white",
  gradient_color_high = "steelblue",
  gridcolor = "black",
  nacolor = NA,
  confmat_xlab = "",
  confmat_ylab = "",
  fontsize = 25,
  imheight = 30,
  imwidth = 30,
  imres = 300,
  filename = "ClusterComparison",
  extraplot = NULL,
  returnplots = FALSE,
  verbose = FALSE
)
}
\arguments{
\item{encodeout1}{User may either pass 1) list output from LIT clustering utilities (dmplot or encodePlot) or 2) an encoded variable formatted as a one-column data formated with rownames}

\item{encodeout2}{User may either pass 1) list output from LIT clustering utilities (dmplot or encodePlot) or 2) an encoded variable formatted as a one-column data formated with rownames}

\item{colorby}{Optional argument. Value used to color the cells in count matrix of joint encoding. Default option is cell 'counts'. Alternatively cells may be colored by Pointwise Mutual Information values using the 'PMI' option.}

\item{simPMI}{Optional argument. When colorby 'PMI', simulation stratedgy used to evaluate significance of PMI values. By default color values are not thresholded. Simulation options include: a permutation-based null model 'NullPerm', a parametric multinomial null model 'NullParam', and a parametric multinomial confidence interval 'CI Param'}

\item{nsim}{Optional argument. When colorby 'PMI', number of simulations to perform to evaluate significance of PMI values. Defulat is 1000 simulations.}

\item{alpha}{Optional argument. When colorby 'PMI', significance threshold used to evaluate significance of PMI values. Default is alpha = 0.05.}

\item{logbase}{Optional argument. When colorby 'PMI', base of log used to calculate PMI values. Default is 2 (shannon's information content)}

\item{gradient_color_low}{Optional argument. Color for lower bound of scale used to color cell values. Default is 'white'}

\item{gradient_color_high}{Optional argument. Color for upper bound of scale used to color cell values. Default is 'steelblue'}

\item{gridcolor}{Optional argument. Color used for lines to outline count matrix. Default is 'black'}

\item{nacolor}{Optional argument. Default is to drop NA values}

\item{confmat_xlab}{Optional argument. Label of row margin of count matrix. Default is no label.}

\item{confmat_ylab}{Optional argument. Label of column margin of count matrix. Default is no label.}

\item{fontsize}{Optional argument. Font size of count values in count matrix cells. Default is 25.}

\item{imheight}{Optional argument. Height of exported image. Default is 30 in.}

\item{imwidth}{Optional argument. Width of exported image. Default is 30.}

\item{imres}{Optional argument. Resolution of exported image. Default is 300,}

\item{filename}{Optional argument. Name of file visualization is exported to. Default filename is 'ClusterComparison'. By default image will be created in working directory. File path may be added to name to modify directory image is exported to.}

\item{extraplot}{Optional argument. User may provide an additional ggplot object to display in upper-left grid of visualization.}

\item{returnplots}{Optional argument. Default is FALSE. If TRUE all component plots are returned in list as ggplot objects.}

\item{verbose}{Optional argument. Default FALSE. If TRUE list is returned with summary stats for the joint encoding.}
}
\value{
If verbose is FALSE, visualizations will be exported to jpeg files. If verbose is TRUE, a list object will also be returned containing

\item{PlotList}{If returnplots is TRUE, a list of ggplot objects used to construct the construct the composite visualization. If returnplot is FASE will return NULL}
\item{counts}{Observed count matrix of the joint encoding}
\item{obsfreq}{Observed empirical frequencies of the joint encoding}
\item{dirchletmeans}{Dirichlet's corrected frequencies of the joint encoding}
\item{nullfreq}{Expected joint frequency under the null assumption that no association exists between the two axes, calculated as the outer product of the marginal frequencies}
\item{PMI}{Pointwise mutual information of the joint encodings}
\item{PMIThresholded}{Pointwise mutual information values thresholded such that statistically insignificant estimates are set to zero}
\item{simquantile_lowerbound}{lower quantile bound of the simulated PMI values}
\item{simquantile_upperbound}{upper quantile bound of the simulated PMI values}
}
\description{
\code{compareEncodings} generates visualizations that facilitate direct comparisons between two encodings. A count matrix is created to assess the distribution of the joint encoding. Visualizations are then extracted from clustering output and added to margins of the count matrix to allow for direct comparison of patterns underlying either encodings.
}
\details{
compareEncodings generates a count matrix of the jointly encoded encoding. If the user provides output from other LIT clustering utilities, then visualizations of the raw data are extracted added to the appropriate table margin, wherein the order of the heatmap dendrogram will match the index of the table margin. An encoding may also be passed as a data frame, in which case a ggplot histogram will be generated and added the the appropriate margin. The resulting data visualization will allow users to directly compare encoded patterns in the raw observations across datasets.

By default the count matrix cells are colored by the cell count to further facilitate visual evaluation of the joint distribution. If there is not association between the two data streams, then it is expected that the frequency of each cell in the joint probability distribution will mirrior the product of the two marginal distribution for either variable. For empirically encoded data, however, cluster sizes can vary substancially, which can make if difficult to judge by eye were cells are under- or over- populated relative the marginal probabilities. The 'PMI' colorby option allows the user to color cells by pointwise mutual information values to directly compare observed cell frequencies against the frequency under the null to facilitate such visual comparisons.

Where data may be under-sampled, empirical estimates of PMI can have poor precision, particularly for cells where the population frequency is quite low, which can confound direct visual comparison. The compareEncodings utility thus also allso users to threshold PMI values, only coloring a cell if simulations confirm that a PMI value is significantly higher or lower than 0 using. With the NullPerm simulation option, observed PMI value are compared against values simulated under the null that no significant association exists between the two variables, which is simulated by randomly permuting indexes of the encoded values before recomputing the count matrix (perserving the marginal distribution). With the NullParam simulation option, observed PMI values are compared against values simulated under the null that no significant association exists between the two variables, which is simulated redrawing from multinomial using the products of the observed marginal freuqncies after Dirchilets correction of the joint joints. Finally, with the CIParam option, a confidence interval is approximated about each observed PMI, wherein the multinomal with expected probabilities equal to the Dirichlet's correct joint empirical frequncies is used to simulate the observed count matrix.
}
\examples{

library(labstats)
data(locomotor)

locowide <- unstack(locomotor, dist~time)
rownames(locowide) <- paste('Rat', unique(locomotor$animal), sep = '')
names(locowide) <- c('Min15', 'Min30','Min45','Min60','Min75','Min90')

auxrow <- unique(locomotor[, c('animal', 'drug')])
rownames(auxrow) <- paste('Rat', auxrow$animal, sep = '')
auxrow <- auxrow[,'drug', drop = F]
names(auxrow) <- 'Treatment'

encodeout_ward <- encodePlot(locowide, dist(locowide), dist(t(locowide)),
                    hclust_method_r = "ward.D2",
                    n_rowclusters = 5, n_colclusters = 0,
                    plot_title = 'Rat Locomotion Pattern: Wards D2 Encoding',
                    annotation_row = auxrow)

encodeout_single <- encodePlot(locowide, dist(locowide), dist(t(locowide)),
                    hclust_method_r = "single",
                    n_rowclusters = 5, n_colclusters = 0,
                    plot_title = 'Rat Locomotion Pattern: Single Encoding',
                    annotation_row = auxrow)

compareEncodings(encodeout_ward$nrow_5_ncol_0,
                 encodeout_single$nrow_5_ncol_0)

}
