% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cutreeEnsemble.R
\name{cutreeEnsemble}
\alias{cutreeEnsemble}
\title{Recursively Test for Branch Significance
\code{cutreeEnsemble} applies the testBranch utility recusively through a dendrogram, working down each branch and pruning the tree where it detects the signal has fallen below the resolution of the data set based simulated error model in the ensemble of mimicked data sets.}
\usage{
cutreeEnsemble(
  obsdat,
  simdata,
  rawdata,
  nclustalt = NULL,
  B = 2000,
  maxiter = 2000,
  feature_subset = NULL,
  hclust_method = "ward.D2",
  dist_method = "Euclidean",
  weightdist = NULL,
  SimSpecs = NULL,
  logbase = 2,
  showmSimPlots = FALSE,
  verbose = F,
  showDendrogram = TRUE,
  showHeatmap = T,
  exportPlots = F,
  filename = "EnsembleCutPlot",
  imSpecDend = list(imwidth = 10, imheight = 20, imres = 300),
  imSpecHeatmap = list(imwidth = 12, imheight = 18),
  imres = 300,
  ...
)
}
\arguments{
\item{obsdat}{Data matrix or array with observational units on the row axis. If data is generated through repeated sampling, time will be indexed on the second index, and features on the third and final axis. If data is not time indexed, features should be on the column axis}

\item{simdata}{Ensemble of data matrices simulated under the alternative hypothesis. Axes indices should match that observed data, with simulation index on the final axis.}

\item{rawdata}{Data array containing raw observations prior to any temporal aggregation.}

\item{nclustalt}{Optional integer argument. By default, if branch test with binary encoding is insignificant, branch will be pruned. User may elect to re-test branch with an alternative encoding granularity >2.}

\item{maxiter}{Optional argument. Maximum size that simulation under the alternative may be extended. Default is 2000. May be set to size of presimulated data set to prevent additional simulations from being performed to resolve ambiguous branch tests}

\item{feature_subset}{Optional argument. Default is to use all features in calculating dissimilarity values. User may pass a vector of feature names to calculate dissimilarity values for only a subset of features.}

\item{hclust_method}{Optional argument. Agglomeration method employed to create dendrogram. Default is 'ward.D2'. See hclust for more options.}

\item{dist_method}{Optional argument. Dissimilarity estimate used to encode data. Options are 'Euclidean', 'KLD, or 'Ensemble'. Default is Euclidean.}

\item{weightdist}{Optional argument. Precomputed weight values that may be used to calculate ensemble weighted distances. See ensembleDist for more details}

\item{SimSpecs}{Optional argument. Structured list containing all specifications needed to parameterize a simulated time budget. See simTimeBudget for formatting details}

\item{logbase}{Optional argument. Logarithm base to use in computing entropic values. Default is 2 (Shannon's Entropy).}

\item{showmSimPlots}{Optional logical argument. Default is FALSE. Should visualizations of the testBranch results for each evaluated branch be returned to screen.}

\item{verbose}{Optional logical argument. Default is FALSE. Should recursion results return more comprehensive simulation reslts. See testBranch for details.}

\item{showDendrogram}{Optional logical argument. Default is TRUE. Should a dendrogram visualization with branch colors set to reflect final pruning results be returned to screen.}

\item{showHeatmap}{Optional logical argument. Default is TRUE. Should a heatmap visualization with gaps between rows to reflect pruned branches be returned to screen.}

\item{exportPlots}{Optional logical argument. Default is FALSE. Should dendrogram and heatmap visualizations be exported as image files.}

\item{filename}{Optional argument. If exportPlots is TRUE, file name and location for image export.}

\item{imSpecDend}{Optional argument. If exportPlots is TRUE, list with specification for imwidth, imheight, and imres of dendrogram image. Default is list(imwidth = 10, imheight = 20, imres = 300)}

\item{imSpecHeatmap}{Optional argument. If exportPlots is TRUE, list with specification for imwidth, imheight, and imres of heatmap image. Default is list(imwidth = 12, imheight = 18, imres = 300)}

\item{...}{additional plotting options may be passed directly to pheatmap plot}
}
\value{
A structured list containing:

\item{SimResults}{A list containing testBranch results for each branch tested}
\item{FinalEncoding}{Vector containing discretely encoded observations based on the pruned dendrogram}
\item{Dendrogram}{hclust object containing the complete tree for the observed data set}
\item{DendrogramPlot}{ggplot object containing visualization of the complete tree for the observed data set, wherein branchess are colored to reflect the final pruning}
\item{Heatmap}{pheatmap visualization of the observed data with gaps along the row axis to indicate the pruned branches}
}
\description{
Recursively Test for Branch Significance
\code{cutreeEnsemble} applies the testBranch utility recusively through a dendrogram, working down each branch and pruning the tree where it detects the signal has fallen below the resolution of the data set based simulated error model in the ensemble of mimicked data sets.
}
\details{
When cutting/prunning a tree to generate clusters (ie - an encoding), the ultimate goal is to pick the point where where signal ends and we get into the stochastic weeds below the intrinsic resoluation of the data. When we do this by visual inspection, we look for a sudden drop off in branch length, but such decisions can be subjective and poorly replicable. More often trees are pruned at a fixed branch height, but for data sets whose metrics are distributed with nonhomogenous variance, branch lengths cannot be directly compared.

Ensemble cut recursively tests the statistical significance of each branch using the testBranch utility. This more localized approach allows for a more adaptive pruning that can accomodate more complex error structures without uncessesary loss of information in the final encoding.
}
