% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dmplot.R
\name{dmplot}
\alias{dmplot}
\title{Generate a data mechanics plot.}
\usage{
dmplot(
  obsdata,
  n_rowclusters = 1,
  n_colclusters = 1,
  hclust_method = "ward.D2",
  maxreps = 10,
  verbose = FALSE,
  showplot_final = TRUE,
  showplot_all = FALSE,
  plot_title = "Data Mechanics Plot",
  export_plot_final = FALSE,
  export_plot_all = FALSE,
  imwidth = 10,
  imheight = 15,
  imres = 300,
  filename = "DatMechPlotOut",
  rorderdend = TRUE,
  corderdend = TRUE,
  ...
)
}
\arguments{
\item{obsdata}{A data frame with observations on the row axis and features on the column axis. Where features differ in magnitude, users are advised to normalized by column.}

\item{n_rowclusters}{Scaler value indicating the number of clusters used to partition row axis}

\item{n_colclusters}{Scaler value indicating the number of clusters used to partition column axis}

\item{hclust_method}{Optional arguement. String indicating the clustering method used to creat hc tree. Default is Ward D2. See hclust for additional options.}

\item{maxreps}{Optional arguement. Maximum number of interations used to converge towards final clustering.}

\item{verbose}{Optional arguement. TRUE/FALSE. Should iteration results and column/row distance matrix be included in output list. Defualt is FALSE.}

\item{showplot_final}{Optional arguement. TRUE/FALSE. Should final plot be returned to screen. Default is TRUE}

\item{showplot_all}{Optional arguement. TRUE/FALSE. Should plots of intermediate clustering results be returned to screen. Default if FALSE}

\item{plot_title}{Optional arguement. Title of data mechanics plot.}

\item{export_plot_final}{Optional arguement. TRUE/FALSE. Should final plot be exported to jpg to current working directors. Default is FALSE}

\item{export_plot_all}{Optional arguement. TRUE/FALSE. Should intermediate plots before clustering converges be exported to jpg to current working directory. Default is FALSE}

\item{imwidth}{Optional arguement. Width of exported jpeg plot.}

\item{imheight}{Optional arguement. Height of exprted jpeg plot.}

\item{imres}{Optional arguement. Resolution of exported jpeg.}

\item{filename}{Optional arguement. File path and name of data mechanics plots exported to jpeg.}

\item{rorderdend}{Optional arguement. Should cluster numbers for final row clusters match the order of the dendrogram or order of appearance in data. Default is order of dendrogram. (Note - Iteration results will order cluster numbers by data as default stats::cutree)}

\item{corderdend}{Optional arguement. Should cluster numbers for final col clusters match the order of the dendrogram or order of appearance in data. Default is order of dendrogram. (Note - Iteration results will order cluster numbers by data as default stats::cutree)}

\item{...}{Aditional plotting options passed directly to pheatmap.}
}
\value{
Returns a list containing
\item{plot}{Heatmap plot where row and column orderings and divisions are determined by ouput of data mechnics optimizations}
\item{coltree}{hclust trees corresponding to the column axis}
\item{rowtree}{hclust trees corresponding to the row axis}
\item{colclust}{vectors with clustering assigmnets to each feature column in the order provided in obsdata}
\item{rowclust}{vectors with clustering assigmnets to each observation row in the order provided in obsdata}
\item{coldist}{distance matrices generated by data mechanics optimization to create the row and column trees}
\item{coldist}{distance matrices generated by data mechanics optimization to create the column tree}
\item{rowdist}{distance matrices generated by data mechanics optimization to create the row tree}
\item{iteration_results}{list containing intermediate clustering results and plots prior convergence of data mechanics optimization}
}
\description{
\code{dmplot} performs a data mechanics clustering on the row and column axes of a data frame and displays the results using the pheatmap packaging plotting options
}
\examples{
library(labstats)
data(locomotor)

trtrats <- locomotor[locomotor$drug == 'Drug',]
locowide <- unstack(trtrats, dist~time)
rownames(locowide) <- paste('Rat', unique(trtrats$animal), sep = '')
names(locowide) <- c('Min15', 'Min30','Min45','Min60','Min75','Min90')

dmout <- dmplot(locowide, n_rowclusters = 3, n_colclusters = 4,
                showplot_all = F, showplot_final = T,
                plot_title = 'Rat Data Mechanics Plot')


locowide <- unstack(locomotor, dist~time)
rownames(locowide) <- paste('Rat', unique(locomotor$animal), sep = '')
names(locowide) <- c('Min15', 'Min30','Min45','Min60','Min75','Min90')
auxrow <- unique(locomotor[, c('animal', 'drug')])
rownames(auxrow) <- paste('Rat', auxrow$animal, sep = '')
auxrow <- auxrow[,'drug', drop = F]
names(auxrow) <- 'Treatment'

dmout <- dmplot(locowide, n_rowclusters = 3, n_colclusters = 4,
                showplot_all = F, showplot_final = T,
                plot_title = 'Rat Data Mechanics Plot',
                annotation_row = auxrow)

}
