% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/encodePlot.R
\name{encodePlot}
\alias{encodePlot}
\title{Encode Data & Visualize Heatmap}
\usage{
encodePlot(
  datmat,
  distrow,
  distcol,
  hclust_method_r = "ward.D2",
  hclust_method_c = "ward.D2",
  n_rowclusters = 1,
  n_colclusters = 1,
  rorderdend = TRUE,
  corderdend = TRUE,
  plot_title = "Encoding Visualization",
  showplot = TRUE,
  exportplot = FALSE,
  imwidth = 10,
  imheight = 17,
  imres = 300,
  filename = "EncodePlotOut",
  exportdendrogram = FALSE,
  dendheight = 8,
  dendwidth = 18,
  ...
)
}
\arguments{
\item{datmat}{Data frame containing the data to be clustered. Rownames of data frame must match labels of distance matrix provided.}

\item{distrow}{Distance matrix containing dissimilarity estimates comparing information content of each row index.}

\item{distcol}{Distance matrix containing dissimilarity estimates comparing information content of each column index.}

\item{n_rowclusters}{Optional argument. Number of clusters used to encode row variable. Default is 1, wherein row order of heatmap visualization will match the dendrogram, but data will not be encoded. User may provide a range of intergers, in which case clustering and visualization routine will be executed on a grid.}

\item{n_colclusters}{Optional argument. Number of clusters used to encode column variable. Default is 1, wherein row order of heatmap visualization will match the dendrogram, but data will not be encoded. If 0 is provided, hclustering will not be preformed and heatmap order will match the order of observations in the dataframe. User may provide a range of intergers, in which case clustering and visualization routine will be executed on a grid.}

\item{rorderdend}{Optional logical arguement. Should the numerical value assigned to each encoded row value match the order that each cluster appears in the dendrogram. Default is TRUE. If FALSE, numerical value will match the order that observations appear in the data set.}

\item{corderdend}{Optional logical arguement. Should the numerical value assigned to each encoded column value match the order that each cluster appears in the dendrogram. Default is TRUE. If FALSE, numerical value will match the order that observations appear in the data set.}

\item{plot_title}{Optional argument. Title of heatmap visualization.}

\item{showplot}{Optional logical argument. Should heatmap visualizations be printed to screen. Default is TRUE. If FALSE heatmap plots are available in list object returned}

\item{exportplot}{Optional logical argument. Should heatmap visualizations be exported to jpeg. Default is FALSE}

\item{imwidth}{Optional argument. Size of image heatmap is exported to. Default is 10 inches.}

\item{imheight}{Optional argument. Size of image heatmap is exported to. Default is 17 inches.}

\item{imres}{Optional argument. Resolution of image heatmap is exported to. Default is 300 dpi.}

\item{filename}{Optional argument. Name of file that heatmap visualization is exported to if exportplot is set to TRUE. By default image will be created in working directory. File path may be added to name to modify directory image is exported to.}

\item{exportdendrogram}{Optional logical argument. Should dendrogram visualizations be exported to jpeg. Default is FALSE}

\item{dendheight}{Optional argument. Size of image dendrogram is exported to. Default is 8 inches.}

\item{dendwidth}{Optional argument. Size of image dendrogram is exported to. Default is 18 inches.}

\item{...}{Additional options passed to pheatmap() plotting utility. If row or column margin annotations are passed, dataframes with this auxiliary data must match the row/column names of the data}

\item{clust_method_r}{Optional argument. Clustering method (modularity estimator) used in the base R hclust utility to cluster rows. Default is ward.D2 method.}

\item{clust_method_c}{Optional argument. Clustering method (modularity estimator) used in the base R hclust utility to cluster column. Default is ward.D2 method.}
}
\value{
Returns a list of lists. Each sublist is indexed by the parameters used to generate a given row and column encoding, and contains the following information:
\item{rowtree}{Hclust ouput for the row axis}
\item{coltree}{Hclust ouput for the column axis}
\item{rowclust}{Vector containing the encoding for row observations, with index names matching the label names of the dendrogram extracted from the corresponding dissimilarity matrix}
\item{colclust}{Vector containing the encoding for column observations, with index names matching the label names of the dendrogram extracted from the corresponding dissimilarity matrix}
\item{plot}{Plotting object for the heatmap visualization returned by pheatmap}
}
\description{
\code{encodePlot} accepts raw data matrix and distance matrices for row and column margins, and from these inputs returns a formated list output with results of hcluster analysis, with options to export heatmap visualizations to working directory
}
\details{
encodePlot encodes the information in the raw data matrix using the dissimilarity values provided by the user via a standard hclustering routine. The user is provided a discrete encodings, dendrogram information, and heatmap visualizations in a format this is compatable for downstream analysis LIT analysis and visualization utilities.
}
\examples{

library(labstats)
data(locomotor)

trtrats <- locomotor[locomotor$drug == 'Drug',]
locowide <- unstack(trtrats, dist~time)
rownames(locowide) <- paste('Rat', unique(trtrats$animal), sep = '')
names(locowide) <- c('Min15', 'Min30','Min45','Min60','Min75','Min90')


encodeout <- encodePlot(locowide, dist(locowide), dist(t(locowide)),
                    n_rowclusters = 1:5, n_colclusters = 3,
                    plot_title = 'Rat Locomotion Pattern Encoding')


locowide <- unstack(locomotor, dist~time)
rownames(locowide) <- paste('Rat', unique(locomotor$animal), sep = '')
names(locowide) <- c('Min15', 'Min30','Min45','Min60','Min75','Min90')
auxrow <- unique(locomotor[, c('animal', 'drug')])
rownames(auxrow) <- paste('Rat', auxrow$animal, sep = '')
auxrow <- auxrow[,'drug', drop = F]
names(auxrow) <- 'Treatment'

encodeout <- encodePlot(locowide, dist(locowide), dist(t(locowide)),
                    n_rowclusters = 1:5, n_colclusters = 0,
                    plot_title = 'Rat Locomotion Pattern Encoding',
                    annotation_row = auxrow)

}
