% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getEncoding.R
\name{getEncoding}
\alias{getEncoding}
\title{Create Discrete Encoding}
\usage{
getEncoding(
  x,
  nclust = 2,
  dist_method = "Euclidean",
  hclust_method = "ward.D2",
  simdata = NULL,
  weightdist = NULL,
  returnTree = FALSE
)
}
\arguments{
\item{x}{Data matrix or data frame, with observational units arranges in the rows and features on the columns}

\item{nclust}{Optional argument. Number of clusters to extract to form discrete encoding. Default is 2 for binarization.}

\item{dist_method}{Optional argument. Dissimilarity estimate used to encode data. Options are 'Euclidean', 'KLD, or 'Ensemble'. Default is Euclidean.}

\item{hclust_method}{Optional argument. Agglomeration method employed to create dendrogram. Default is 'ward.D2'. See hclust for more options.}

\item{simdata}{Optional argument. Simiulated data set used to calculate ensemble weighted distances. See ensembleDist for more details.}

\item{weightdist}{Optional argument. Precomputed weight values that may be used to calculate ensemble weighted distances. See ensembleDist for more details.}

\item{returnTree}{Optional logical argument. Default is FALSE. Should dendrogram used to create encoding also be returned}
}
\value{
If returnTree iss FALSE, only a vector with encoded values is returned. If returnTree is TRUE, a named list is returned that also containing:

\item{cluster}{Vector containing discrete encoding that matches row index of the original data}
\item{hctree}{Dendrogram object from which the discrete encoding is derived}
}
\description{
\code{getEncoding} takes a data set and returns a discrete encoding generated via a heirarchical clustering stratedgy specified by the user
}
\examples{

library(labstats)
data(locomotor)

locowide <- unstack(locomotor, dist~time)
rownames(locowide) <- paste('Rat', unique(locomotor$animal), sep = '')
names(locowide) <- c('Min15', 'Min30','Min45','Min60','Min75','Min90')

discout <- getEncoding(locowide, 4, returnTree = T)
discout$cluster
plot(discout$hctree)

}
