% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/groupTubeplot.R
\name{groupTubeplot}
\alias{groupTubeplot}
\title{Generate a tube plot by grouping variable}
\usage{
groupTubeplot(
  cyc,
  long,
  dat,
  g,
  func = "median",
  na.rm = T,
  subsethour = c(),
  showplot = T,
  plot_title = "TubePlot",
  export_html = F,
  filename = "TubePlot",
  makediffplot = F,
  returnstats = F,
  ...
)
}
\arguments{
\item{cyc}{A numeric vector containing cyclical indexing variable for each observation}

\item{long}{A numeric vector containing longitudinal temporal index for each observation}

\item{dat}{A data frame with a row for each unique timepoint observed and column for each observational unit (ie - animal)}

\item{g}{Vector containing the group assignments for the corresponding columns in dat}

\item{func}{Optional arguement. String specifying base R operation used to summarize data at each time point across each group. Defualt is median.}

\item{na.rm}{Optional arguement. Logical specifying if NA values should be dropped in calculating summarizing statistics for each group. Default is to drop NA values.}

\item{subsethour}{Optional arguement. If a subset of cyclical time indices are provided, data points not selected will be set to grey}

\item{showplot}{Optional argument. Should plot be printed to screen. Default is TRUE}

\item{plot_title}{Optional argument. Title added to plot. Defaults to no title.}

\item{export_html}{Optional argument. Should interactive html file be saved to current working directory. Default is FALSE}

\item{filename}{Optional argument. Name of html file exported to current working directory. Do not include file extension. Default is 'TubePlot'}

\item{makediffplot}{Optional arguement. Calculate the difference between each pairwise observations of groups at each time point and plot the difference. Default is FALSE}

\item{returnstats}{Optional arguement. If TRUE, returns a dataframe with summary statistics computed at each time point for all groups. Default is FALSE}

\item{...}{Additional arguements passed into tubeplot()}
}
\value{
Returns a 3D tubeplot for each group of observational units. Information is compressed at each time point across individuals within the group using a summary statistic, usually a measure of central tendancy such as median or mean. These summary values are then used to determine the value (color) of each marker comprising the tube plot. the makediffplot option will also allow users to return tubeplots representing the contrasts between summary statistics at each time point for all pairwise combination of groups. The returnstats option allows users to return the data frame of summary statistics at each time points for all groups (useful for checking code).
}
\description{
\code{groupTubeplot} calculates a summary statistic (mean, median, etc) at each unique time point across groups of observational units and uses these values to generate a \code{\link{tubeplot}} for each respective group
}
\examples{
v_long <- rep(1:40, each = 24)
v_cyc <- rep(1:24, times = 40)
obsdat <- data.frame(Cow1 = v_cyc + v_long,
                     Cow2 = v_cyc + v_long,
                     Cow3 = v_cyc + 2*v_long,
                     Cow4 = v_cyc + 2*v_long)
cowgroups <- c(1,1,2,2)
groupTubeplot(v_cyc, v_long, obsdat, cowgroups)

}
