% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/permuteEdgeWeights.R
\name{permuteEdgeWeights}
\alias{permuteEdgeWeights}
\title{Conditionally Permute Edge Weights}
\usage{
permuteEdgeWeights(adj, cond = NULL)
}
\arguments{
\item{adj}{An adjacency matrix. Must be  symmetric and formatted as a matrix.}

\item{cond}{Optional argument. A symmetric matrix with dimensions equivalent to the corresponding adjacency matrix. Values in this matrix indicate which permutation subgroup each edge in the corresponding index position in the adjacency matrix should be permuted within. Any edges marked as NA in the conj matrix will not be permuted, and by default all NA values in adj matrix will be set to NA in conj}
}
\value{
Returns an adjacency matrix with permuted edge weights. Note that values along diagonal will not be permuted and will be returned as 0's
}
\description{
\code{permuteEdgeWeights} performs a stochastic permutation of edge weight values within a network adjacency matrix, excluding NA edgeweights. Users may provide an additional matrix, conformable with the adjacency, that directs the permutation of edge weights within pre-defined subgroups
}
\examples{

\% permute edges with the same the even/odd modularity

adj <-  matrix(1:100, nrow = 10)
adj[upper.tri(adj, diag = F)] <- 0
adj <- t(adj) + adj
adj

conj <- adj \%\%  2
conj

permuteEdgeWeights(adj, conj)


}
