% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/permuteNetworkTensor.R
\name{permuteNetworkTensor}
\alias{permuteNetworkTensor}
\title{Permute Network Tensor}
\usage{
permuteNetworkTensor(
  tensordat,
  B = 100,
  permutenodes = T,
  auxdat = NULL,
  tensorout = TRUE
)
}
\arguments{
\item{tensordat}{Network tensor array. Each temporally independent adjacency matrix should be defined along the first two dimensions of the array, with temporal dimension as the third axis of the array.}

\item{B}{Number of permutations to generate. Default value is 100.}

\item{permutenodes}{Optional argument. Logical argument indicating if a nodal ID permution should be implemented (default) or an edge permutation.}

\item{auxdat}{Optional argument. Data used to perform a conditioned permutation across subgroups for each indepdendent auxiliary matrix. See details.}

\item{tensorout}{Optional argument. Logical argument indicating if the full network tensor should be returned after permutation (default) or just the weighted adjacency matrix aggregated over the time domain after the permutation is performed.}
}
\value{
List of length B containing either the permuted network tensor arrays or the weighted adjacency matrices
}
\description{
\code{permuteNetworkTensor} independently permutes either the node ID's or edge weights for each adjacency submatrix within the network tensor, allowing for the permutation to be conditioned on auxiliary data.
}
\details{
If a conditional nodal ID permutation is performed, auxdat should be formatted as a data frame. If the conditioning variable is uniform across adjacency matrices, then data frame should have a single column, with rows matching those of the adjacency submatrices in dimension and rownames. If the conditioning variable changes across the time axis, then the number of columns in the auxdat data frame should match the length of the tensor arrays third time dimension, and the names of the auxdat columns must match the names of the third dimension of the tensor array.

If a conditional edge weight permutation is performed, auxdat should be formatted as either an array or a matrix. If the conditioning variable is uniform across adjacency matrices, then a matrix identifcal in size and row/column names to the first two dimensions of the network tensor can be provided. If the conditioning variable changes across the time axis, then an array with equivalent size and dimname specs to that of the network tensor array should be provided.

For more information on how nodal and edge permutations are performed, including how missing observations are handled, see {permuteEdgeWeights} and {permuteNodeID}
}
