% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/permuteNodeID.R
\name{permuteNodeID}
\alias{permuteNodeID}
\title{Conditionally Permute Node IDs}
\usage{
permuteNodeID(dat, auxdat = NULL, auxdatindex = NULL)
}
\arguments{
\item{dat}{An adjacency matrix.}

\item{auxdat}{Optional argument. A data frame containing information on which to condition the node permutation into subgroups. Rownames must match those of the auxiliary matrix provided.}

\item{auxdatindex}{Optional argument. Integer indicating the column index containing the data to condition the permutation upon.}
}
\value{
Returns an adjacency matrix with permuted node IDs
}
\description{
\code{permuteNodeID} performs a stochastic permutation of node ID's within a network adjacency matrix, skipping nodes with only NA edge weights. Users may provide auxiliary data that directs the permutation of node IDs within pre-defined subgroups
}
\details{
Node ID permutations will only be performed on nodes with at least one recorded non-NA value. If auxiliary data is provided on which to condition the node ID permutation, any sows with an NA auxiliary value will not be permuted.
}
\examples{

adj <- matrix(rep(1:10, each = 10), nrow = 10)
adj[upper.tri(adj, diag = T)] <- 0
adj <- adj + t(adj)
adj[c(2,5), ] <- NA
adj[, c(2,5)] <- NA
rownames(adj) <- 1:10
colnames(adj) <- 1:10

auxdat <- data.frame(EvenOdd = rep(1:2, 5))
rownames(auxdat) = rownames(adj)
colnames(auxdat) = colnames(adj)

permuteNodeID(adj)
permuteNodeID(adj, auxdat)

}
