% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pghist.R
\name{pghist}
\alias{pghist}
\title{Generate a possibly-gapped histogram}
\usage{
pghist(
  obs,
  nbins,
  freq = TRUE,
  clustermethod = "ward.D2",
  xlab = "Observed Data",
  main = "Possibly Gapped Histogram",
  col = "slateblue",
  showDendrogram = FALSE,
  showCDFPlot = FALSE,
  returnCluters = FALSE
)
}
\arguments{
\item{obs}{Numeric vector containing the observations of the continous variable to be encoded.}

\item{nbins}{Number of histogram bins (ie - number of categories used to encode data).}

\item{freq}{Optional argument. If TRUE (default) histogram displays frequency of obs in each bin. If FALSE displays density of obs in each bins.}

\item{clustermethod}{Optional argument. Method used to create clusters (see hclust for options). Default is Ward D2.}

\item{xlab}{Optional argument. Label for x-axis of histogram.}

\item{main}{Optional argument. Title of histogram.}

\item{col}{Optional argument. Color of histogram bins}

\item{showDendrogram}{Optional argument. Return plot of dendorgram returned by hclust. Default is FALSE.}

\item{showCDFPlot}{Optional argument. Return plot showing discretized approximation of continuous empirical CDF. Default is FALSE.}

\item{returnCluters}{Optional argument. Return list object containing cluster assignments and details}
}
\value{
Optionally returns a list containing
\item{ClusterSpecs}{Matrix with Min and Max values for each bin}
\item{Encoding}{Vector containing bin assignments (intergers) for each observation in the corresponding obs input vector}
}
\description{
\code{pghist} creates a possibly graphed histogram using hclust, optionally returning a distcretized encoding of the continuous input and additional visualizations
}
\examples{
library(LIT)
set.seed(61916)
obs <- c(rnorm(30, 0, 2), rnorm(30, 10, 1), rnorm(30, 15, 1))
hist(obs, breaks = 12)
mycode <- pghist(obs, 12, returnCluters = TRUE)
data.frame(Obs = obs, Encoding = mycode$Encoding)
}
