% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/relativeEntropy.R
\name{relativeEntropy}
\alias{relativeEntropy}
\title{Calculate Relative Entropy}
\usage{
relativeEntropy(
  p,
  q,
  isFreq = TRUE,
  logbase = 2,
  DirichletCorrection = FALSE,
  Np = NULL,
  Nq = NULL
)
}
\arguments{
\item{p}{Vector of counts/frequencies for an observed distribtuion ('p' in MacKay 2003)}

\item{q}{Vector of counts/frequencies for a distribtuion that is serving as a standard of comparison ('q' in MacKay 2003)}

\item{isFreq}{Optional logical argument. Default is TRUE, indicating p and q are provided as frequencies. User may provide vector of counts if isFreq is FALSE.}

\item{logbase}{Optional argument. Logarithm base to use in computing entropic values. Default is 2 (Shannon's Entropy).}

\item{DirichletCorrection}{Optional logical argument. Default is FALSE. Should a Dirichlets correction be applied to frequency vectors before relative entropy is calculated. Allows for entropy to be calculated if q may contain 0 due to under-sampling}

\item{Np}{Optional argument. If isFreq is TRUE, then a total count must be provided for p in order to compute a Dirichlets correction}

\item{Nq}{Optional argument. If isFreq is TRUE, then a total count must be provided for q in order to compute a Dirichlets correction}
}
\description{
\code{relativeEntropy} computes the relative entropy between two distributions with the same support as in MacKay (2003)
}
\details{
relativeEntropy calculates the relative entropy between two discrete distributions. The two distributions may be provided either as frequency (normalized to sum to 1) or as count vectors, but must have the same domain of support (ie - be the same length)
}
\examples{

pcount <- c(10, 20, 30, 0)
p <- pcount/sum(pcount)

qcount <- pcount  + 1
q1 <- qcount/sum(qcount)
q2 <- rev(pcount + 1)/sum(pcount  + 1)

relativeEntropy(p, q1) # calc relative entropy using frequencies
relativeEntropy(pcount, qcount, isFreq = F)# calc relative entropy using counts
relativeEntropy(p, q2) # q2 has a different underlying pattern, so has higher relative entropy than when q1 is used as reference

relativeEntropy(q1, p) # because p contrains a zero-count, it will return an INF when used as a reference dist
relativeEntropy(qcount, pcount, isFreq = F, DirichletCorrection = T) # applying a Dirichlets correction to get a relative entropy estimate in spite of the zero-count in the reference distribution
relativeEntropy(q1, p, DirichletCorrection = T, Np = sum(qcount), Nq = sum(pcount)) # applying a Dirichlets correction to get a relative entropy estimate in spite of the zero-count in the reference distribution


}
