% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/testBranch.R
\name{testBranch}
\alias{testBranch}
\title{Test for Significant Branching}
\usage{
testBranch(
  obsdat,
  simdata,
  rawdata,
  feature_subset = NULL,
  hclust_method = "ward.D2",
  nclustalt = NULL,
  dist_method = "Euclidean",
  weightdist = NULL,
  SimSpecs = NULL,
  logbase = 2,
  showplot = FALSE,
  verbose = F,
  B = 2000,
  maxiter = 2000
)
}
\arguments{
\item{obsdat}{Data matrix or array with observational units on the row axis. If data is generated through repeated sampling, time will be indexed on the second index, and features on the third and final axis. If data is not time indexed, features should be on the column axis}

\item{simdata}{Ensemble of data matrices simulated under the alternative hypothesis. Axes indices should match that observed data, with simulation index on the final axis.}

\item{rawdata}{Data array containing raw observations prior to any temporal aggregation.}

\item{feature_subset}{Optional argument. Default is to use all features in calculating dissimilarity values. User may pass a vector of feature names to calculate dissimilarity values for only a subset of features.}

\item{hclust_method}{Optional argument. Agglomeration method employed to create dendrogram. Default is 'ward.D2'. See hclust for more options.}

\item{nclustalt}{Optional integer argument. By default, if branch test with binary encoding is insignificant, branch will be pruned. User may elect to re-test branch with an alternative encoding granularity >2.}

\item{dist_method}{Optional argument. Dissimilarity estimate used to encode data. Options are 'Euclidean', 'KLD, or 'Ensemble'. Default is Euclidean.}

\item{weightdist}{Optional argument. Precomputed weight values that may be used to calculate ensemble weighted distances. See ensembleDist for more details}

\item{SimSpecs}{Optional argument. Structured list containing all specifications needed to parameterize a simulated time budget. See simTimeBudget for formatting details}

\item{logbase}{Optional argument. Logarithm base to use in computing entropic values. Default is 2 (Shannon's Entropy).}

\item{showplot}{Optional logical argument. Default is FALSE. If TRUE density plot comparing MI values calculated against the alternative and null simulations is returned}

\item{verbose}{Optional logical argument. Default is FALSE. If TRUE additional simulation results are provided.}

\item{B}{Optional arguement. Number of bootstrap simulations to perform under the null. Default is 2000.}

\item{maxiter}{Optional argument. Maximum size that simulation under the alternative may be extended. Default is 2000. May be set to size of presimulated data set to prevent additional simulations from being performed to resolve ambiguous branch tests}
}
\value{
A structured list containing:
\item{sigdiff}{Logical value indicating if the difference between simulated MI values under the null and the alternative exceeded the bounds of uncertainty of the simulations}
\item{pval}{Proportion of MI values under the alternative that were greater than or equal to the 95th quantile of MI values simulated under the null}
\item{encoding}{Vector containing the discrete encoding of the observed data}
\item{plot}{Density plot comparing MI values calculated against the alternative and null simulations}
\item{dist_method}{Returned if verbose is TRUE. Record of dissimilarity metric used to create hclust encoding}
\item{obsHTree}{Returned if verbose is TRUE. Dendrogram object returned from the heirarchical clustering of the observed data matrix}
\item{thresholdnull}{Returned if verbose is TRUE. Confidence interval for MI values calculated against the simulation under the null hypothesis}
\item{thresholdalt}{Returned if verbose is TRUE. Confidence interval for MI values calculated against the simulation under the alternative hypothesis}
\item{MI_null}{Returned if verbose is TRUE. Vector MI values calculated against the simulation under the null hypothesis}
\item{MI_alt}{Returned if verbose is TRUE. Vector of MI values calculated against the simulation under the alternative hypothesis}
}
\description{
\code{testBranch} uses simulation-based techniques to determine if a branch represents an underlying biological signal that can be reliably differentiated from the intrinsic noise in the system
}
\details{
Does a branch in a dendrogram represent reliable differences between two sets of observations driven by some underlying biological signal, or has a branch moved past the intrinsic resolution of the data set and thus only reflecting random meaningless fluctuations in measurements between observations? The brach test utility strives to answer this question using simulation-based appraches.

Under the alternative, a branch under consideration contains an authentc signal that is only partially obscured by noise. Simulation-based techniques can be employed to create an ensemble of synthetic datasets mimick this noise structure. If the component of the observed data attributable to signal is significantly larger than this noise structure, then independently applying hclustering to each of these simulated data sets should produce a similar encoding to that extracted from the observed data.

Under the null, any signal left in a branch is obscured by noise, and so the clustering is driven by stochastic flucturations. As this implies that all observations are equivalent in the branch up to the intrinsic resolution of the data, a second ensemble of mimicries is simulated under the null by resampling (bootsraping) values from the first mimicry unconditional on observation ID.

Mutual Information is here used to evaluate how similar encodings of each simulated data set are to the encoding generated for the observed data. If a branch contains a signal that can be reliably distinguished from the simulated noise, the mutual information estimates to simulations under the alternative will be significantly higher than MI values evaluated against simulations under the null.

If the 95th quantile of the null distribution falls below the 5th quantile under the alternative, the algorithm terminates, as a significant signal is detected. If an insignificant result is found, and if the user has specified an nclustalt option >2, the test will be repeated with an encoding with more clusters, which can help identify is two or more components of a complex signal with similar magnitudes are competing for branch position and artificially destabilizing the bifurcation. If a result is returned that places the two quantiles within the confidence bounds of the other, the test is repeated after doubling the simulation sizes to increase the overall power of the test. s
}
