% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tubeplot.R
\name{tubeplot}
\alias{tubeplot}
\title{Generate a tube plot}
\usage{
tubeplot(
  cyc,
  long,
  obs,
  radius = 1,
  annotationkey = data.frame(),
  plot_title = "",
  camera_orient = list(eye = list(x = 1, y = 1, z = 0)),
  showplot = T,
  export_html = F,
  filename = "TubePlot",
  export_orca = F,
  orcascale = 10,
  ...
)
}
\arguments{
\item{cyc}{A numeric vector containing cyclical indexing variable for each observation}

\item{long}{A numeric vector containing longitudinal temporal index for each observation}

\item{obs}{The observed value for each data point (ie - color of points). May be either continous or categorical}

\item{radius}{Optional argument. The radius of circle plotted for the cyclical axis. Default radius. Defualts to 1.}

\item{annotationkey}{Optional argument. A data frame mapping the numerical values given in c to text labels for cyclical time index. Defualts to no labels.}

\item{plot_title}{Optional argument. Title added to plot. Defaults to no title.}

\item{camera_orient}{Optional argument. Initial orientation of tube plot. Useful in defining correct orientation for generating still images. List with options for plotly camera settings. Defaults to list(eye = list(x = 1, y = 1, z = 0)}

\item{showplot}{Optional argument. TRUE/FALSE. Should plot be printed to screen. Default is TRUE}

\item{export_html}{Optional argument. TRUE/FALSE. Should interactive html file be saved to current working directory. Default is FALSE}

\item{filename}{Optional argument. Name of html file exported to current working directory. Do not include file extension. Default is 'TubePlot'}

\item{export_orca}{Optional argument. TRUE/FALSE. Should plot be exported to still jpeg image. Defaults to FALSE.}

\item{orcascale}{Optional argument. Size of orca jpeg image.}

\item{...}{Additional plotting options passed to plotly. Used to control color scheme, marker formate, etc.}
}
\value{
Returns a 3D plot wherein observations appear as markers that are colored based on their observed value \code{obs} and arranged so that cyclical time indices \code{cyc} determine their arangement around the radius of the tube and longitudinal indices \code{long} determine their position along the shaft of the tube.
}
\description{
\code{tubeplot} creates a tube plot using the plotly package to visually display cyclical and longitudinal patterns in observed data.
}
\examples{
v_cyc <- rep(1:24, times = 40)
v_long <- rep(1:40, each = 24)
v_obs <- v_cyc + v_long
tubeplot(v_cyc, v_long, v_obs)

}
